.. nxswriter documentation master file, created by
   sphinx-quickstart on Wed Apr  6 14:24:33 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. default-domain:: py
		       
.. include:: ../README.rst

Contents
========

.. toctree::
   :maxdepth: 4

	      
   nxswriter
   

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

